"use strict";
// Licensed Materials - Property of IBM
//
// IBM Watson Analytics
//
// (C) Copyright IBM Corp. 2019, 2020
//
// US Government Users Restricted Rights - Use, duplication or
// disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
Object.defineProperty(exports, "__esModule", { value: true });
exports.info = void 0;
const fs = require("./utils/fs");
const path = require("path");
const findCustomvisLibPath_1 = require("./utils/findCustomvisLibPath");
/**
 * Get info about the the current bundle.
 * @param _path The absolute path where the bundle is located.
 * @returns A promise that resolves with a string holding the (formatted) information.
 */
async function info(_path) {
    const cliVersion = (await fs.readJSON(path.resolve(__dirname, "../package.json"))).version;
    const visPkgPath = path.join(_path, "package.json");
    let libVersion = "";
    let rsVersion = "";
    let metaInfo = null;
    // Get metaInfo, rsVersion and libVersion from bundle and customvis-lib.
    const visPkg = await fs.readJSON(visPkgPath).catch(fs.suppressENOENT);
    if (visPkg) // If there is a package.json, assume this is a development folder of a vizbundle
     {
        metaInfo = visPkg.meta || null;
        // Check if lib package is installed (in node_modules).
        const libPath = findCustomvisLibPath_1.findCustomvisLibPath(_path);
        const libPkg = await fs.readJSON(libPath).catch(fs.suppressENOENT);
        if (libPkg) {
            libVersion = libPkg.version;
            rsVersion = libPkg.apiversion || rsVersion;
        }
    }
    else {
        metaInfo = await fs.readJSON(path.join(_path, "meta.json")).catch(fs.suppressENOENT);
        if (metaInfo) {
            rsVersion = metaInfo.apiVersion;
            libVersion = metaInfo.libVersion;
        }
    }
    // At least show the customvis CLI version.
    const cliInfo = `Customvis CLI
    version: ${cliVersion}`;
    // If we found any meta info, fill in the rest of the Visualization info.
    return metaInfo ? `${cliInfo}

    Visualization
        id: ${metaInfo.id}
        name: ${metaInfo.name},
        description: ${metaInfo.description}
        icon: ${metaInfo.icon}
        version: ${metaInfo.version}

        customvis-lib: ${libVersion || "not found"}
        rs-version: ${rsVersion || "not found"}` : cliInfo;
}
exports.info = info;
